import { NativeEventEmitter, NativeModules } from "react-native";

const _RNAudioDevice = NativeModules.RNAudioDevice;
const DeviceInfoEventEmitter = new NativeEventEmitter(_RNAudioDevice);
const _subscriptions = new Map();

class RNAudioDevice {
  constructor() {}

  addEventListener(eventName, handler) {
    const listener = DeviceInfoEventEmitter.addListener(
      eventName,
      (appStateData) => {
        handler({
          data: appStateData,
        });
      }
    );

    _subscriptions.set(handler, listener);
    return {
      remove: () => RNAudioDevice.removeEventListener(eventName, handler),
    };
  }

  /**
   * Removes the listener for network status changes.
   */
  removeEventListener(eventName, handler) {
    const listener = _subscriptions.get(handler);
    if (!listener) {
      return;
    }
    listener.remove();
    _subscriptions.delete(handler);
  }

  // Start device management thread
  start() {
    _RNAudioDevice.start();
  }

  // Stop device management thread
  stop() {
    _RNAudioDevice.stop();
  }

  // StartRecognize for audio.
  startRecognize(isRecordable) {
    _RNAudioDevice.startRecognize(isRecordable);
  }

  // StopRecognize for audio.
  stopRecognize() {
    _RNAudioDevice.stopRecognize();
  }

  // Enable/Disable spearker phone
  setSpeakerphoneOn(enable) {
    enable = enable === true ? true : false;
    _RNAudioDevice.setSpeakerphoneOn(enable);
  }

  setMicrophoneMute(enable) {
    enable = enable === true ? true : false;
    _RNAudioDevice.setMicrophoneMute(enable);
  }
}

export default new RNAudioDevice();
